@@ -70,18 +70,6 @@ D64::Disk::Dir::Item - Handling individual Commodore (D64/D71/D81) disk image di
   # Validate item data against all possible errors:
   my $is_valid = $item->validate();
 
-  # Check if directory item contains information about the actual disk file:
-  my $is_empty = $item->empty();
-
-  # Check if directory item is writable and can be replaced by any new file:
-  my $is_writable = $item->writable();
-
-  # Clone disk directory item:
-  my $clone = $item->clone();
-
-  # Check if filename matches given CBM ASCII pattern:
-  my $is_matched = $item->match_name($petscii_pattern);
-
   # Convert any given file type into its three-letter printable string representation:
   my $string = D64::Disk::Dir::Item->type_to_string($type);
 
@@ -98,78 +86,38 @@ use strict;
 use utf8;
 use warnings;
 
-our $VERSION = '0.08';
-
-use parent 'Clone';
+our $VERSION = 0.01;
 
 use Data::Dumper;
 use Readonly;
 use Scalar::Util qw(looks_like_number);
-use Text::Convert::PETSCII qw(:convert);
+use Text::Convert::PETSCII qw(:all);
 use Try::Tiny;
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
-# Setup package constant names:
-our (
-    # File type constant names:
-    $T_DEL, $T_SEQ, $T_PRG, $T_USR, $T_REL, $T_CBM, $T_DIR,
+# File type constants:
+Readonly our $T_DEL => 0b000;
+Readonly our $T_SEQ => 0b001;
+Readonly our $T_PRG => 0b010;
+Readonly our $T_USR => 0b011;
+Readonly our $T_REL => 0b100;
+Readonly our $T_CBM => 0b101;
+Readonly our $T_DIR => 0b110;
 
-    # Data offset constant names:
-    $I_TYPE, $I_NAME, $I_CLOSED, $I_LOCKED,
-    $I_TRACK, $I_SECTOR, $I_SIZE_LO, $I_SIZE_HI,
-    $I_SIDE_TRACK, $I_SIDE_SECTOR, $I_RECORD_LENGTH,
-
-    # Other package constant names:
-    $ITEM_SIZE,
-);
-
-# File type constant values:
-my %file_type_constants = (
-    T_DEL => 0b000,
-    T_SEQ => 0b001,
-    T_PRG => 0b010,
-    T_USR => 0b011,
-    T_REL => 0b100,
-    T_CBM => 0b101,
-    T_DIR => 0b110,
-);
-
-# Data offset constant values:
-my %data_offset_constants = (
-    I_TYPE          => 0x00,
-    I_CLOSED        => 0x00,
-    I_LOCKED        => 0x00,
-    I_TRACK         => 0x01,
-    I_SECTOR        => 0x02,
-    I_NAME          => 0x03,
-    I_SIDE_TRACK    => 0x13,
-    I_SIDE_SECTOR   => 0x14,
-    I_RECORD_LENGTH => 0x15,
-    I_SIZE_LO       => 0x1c,
-    I_SIZE_HI       => 0x1d,
-);
-
-# Other package constant values:
-my %other_package_constants = (
-    ITEM_SIZE => 0x1e,
-);
-
-# Setup package constant values:
-my %all_constants = (%file_type_constants, %data_offset_constants, %other_package_constants);
-while (my ($name, $value) = each %all_constants) {
-    if ($] < 5.008) {
-        eval sprintf q{
-            Readonly \\$%s => %d;
-        }, $name, $value;
-    }
-    else {
-       eval sprintf q{
-            Readonly $%s => %d;
-        }, $name, $value;
-    }
-}
+# Data offset constants:
+Readonly our $I_TYPE          => 0x00;
+Readonly our $I_CLOSED        => 0x00;
+Readonly our $I_LOCKED        => 0x00;
+Readonly our $I_TRACK         => 0x01;
+Readonly our $I_SECTOR        => 0x02;
+Readonly our $I_NAME          => 0x03;
+Readonly our $I_SIDE_TRACK    => 0x13;
+Readonly our $I_SIDE_SECTOR   => 0x14;
+Readonly our $I_RECORD_LENGTH => 0x15;
+Readonly our $I_SIZE_LO       => 0x1c;
+Readonly our $I_SIZE_HI       => 0x1d;
 
 use base qw(Exporter);
 our %EXPORT_TAGS = ();
@@ -178,6 +126,8 @@ $EXPORT_TAGS{'all'} = [ @{$EXPORT_TAGS{'types'}} ];
 our @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 our @EXPORT = qw();
 
+Readonly our $ITEM_SIZE => 0x1e;
+
 =head2 new
 
 Create an instance of a C<D64::Disk::Dir::Item> class as an empty directory entry:
@@ -715,9 +665,7 @@ sub size {
     my $size_lo = unpack 'C', $self->[$I_SIZE_LO];
     my $size_hi = unpack 'C', $self->[$I_SIZE_HI];
 
-    # Since a scalar value of a double type (NV) will always be loaded as the result
-    # of multiplication in Perl 5.6.2, we need to force an integer value into an SV:
-    return $self->set_iok($size_lo + 256 * $size_hi);
+    return $size_lo + 256 * $size_hi;
 }
 
 =head2 exact_size
@@ -742,9 +690,9 @@ sub exact_size {
 
 Print out formatted disk image directory item:
 
-  $item->print(fh => $fh, as_petscii => $as_petscii, verbose => $verbose);
+  $item->print(fh => $fh, as_petscii => $as_petscii);
 
-C<fh> defaults to the standard output. C<as_petscii> defaults to false (meaning that ASCII characters will be printed out by default). C<verbose> defaults to false (changing it to true will additionally print out file's track and sector values).
+C<fh> defaults to the standard output. C<as_petscii> defaults to false (meaning that ASCII characters will be printed out by default).
 
 =cut
 
@@ -753,7 +701,6 @@ sub print {
 
     my $fh = $args{fh};
     my $as_petscii = $args{as_petscii};
-    my $verbose = $args{verbose};
 
     $fh ||= *STDOUT;
     $fh->binmode(':bytes');
@@ -761,36 +708,15 @@ sub print {
     my $stdout = select $fh;
 
     if ($as_petscii) {
-        my $type = $self->type_to_string($self->type(), 1);
-        my $closed = $self->closed() ? 0x20 : 0x2a; # "*"
-        my $locked = $self->locked() ? 0x3c : 0x20; # "<"
-        my $track = sprintf "%2d", $self->track();
-        my $sector = sprintf "%2d", $self->sector();
-        my $size = ascii_to_petscii($self->size());
-        my $name = sprintf "\"%s\"", $self->name(padding_with_a0 => 0);
-        $name =~ s/\x00//g; # align file type string to the right column
-        if ($verbose) {
-          printf "%-4d %-18s%c%s%c %s %s\n", $size, $name, $closed, $type, $locked, $track, $sector;
-        }
-        else {
-          printf "%-4d %-18s%c%s%c\n", $size, $name, $closed, $type, $locked;
-        }
+        print $fh $self->data();
     }
     else {
         my $type = $self->type_to_string($self->type());
         my $closed = $self->closed() ? ord ' ' : ord '*';
         my $locked = $self->locked() ? ord '<' : ord ' ';
-        my $track = sprintf "%2d", petscii_to_ascii $self->track();
-        my $sector = sprintf "%2d", petscii_to_ascii $self->sector();
         my $size = $self->size();
         my $name = sprintf "\"%s\"", petscii_to_ascii($self->name(padding_with_a0 => 0));
-        $name =~ s/\x00//g; # align file type string to the right column
-        if ($verbose) {
-          printf "%-4d %-18s%c%s%c %s %s\n", $size, $name, $closed, $type, $locked, $track, $sector;
-        }
-        else {
-          printf "%-4d %-18s%c%s%c\n", $size, $name, $closed, $type, $locked;
-        }
+        printf "%-4d  %-18s%c%s%c\n", $size, $name, $closed, $type, $locked;
     }
 
     select $stdout;
@@ -870,144 +796,32 @@ sub validate {
     return $is_valid;
 }
 
-=head2 empty
-
-Check if directory item contains information about the actual disk file:
-
-  my $is_empty = $item->empty();
-
-True value will be returned when directory item object is empty.
-
-=cut
-
-sub empty {
-    my ($self) = @_;
-
-    my $is_empty = not grep { ord ($_) != 0x00 } @{$self};
-
-    return $is_empty;
-}
-
-=head2 writable
-
-Check if slot occupied by this item in a disk directory is writable and can be replaced by any new file that would be written into disk:
-
-  my $is_writable = $item->writable();
-
-True value will be returned when directory item object is writable.
-
-=cut
-
-sub writable {
-    my ($self) = @_;
-
-    my $is_writable = !$self->closed() && $self->type() eq $T_DEL;
-
-    return $is_writable;
-}
-
-=head2 clone
-
-Clone disk directory item:
-
-  my $clone = $item->clone();
-
-=head2 match_name
-
-Check if filename matches given CBM ASCII pattern:
-
-  my $is_matched = $item->match_name($petscii_pattern);
-
-C<$petscii_pattern> is expected to be a CBM ASCII string containing optional wildcard characters. The following wildcards are allowed/recognized:
-
-=over
-
-=item *
-An asterisk C<*> character following any program name will yield successful match if filename is starting with that name.
-
-=item *
-A question mark C<?> character used as a wildcard will match any character in a filename.
-
-=back
-
-=cut
-
-sub match_name {
-    my ($self, $petscii_pattern) = @_;
-
-    my $name = $self->name(padding_with_a0 => 0);
-
-    my @name = split //, $name;
-    my @pattern = split //, $petscii_pattern;
-
-    for (my $i = 0; $i < @pattern; $i++) {
-        my $match_pattern = ord $pattern[$i];
-        if ($match_pattern == 0x2a) {
-            return 1;
-        }
-        my $character = $name[$i];
-        unless (defined $character && $match_pattern == 0x3f) {
-            if (!defined $character || ord $character != $match_pattern) {
-                return 0;
-            }
-        }
-    }
-
-    if (@name == @pattern) {
-        return 1;
-    }
-
-    return 0;
-}
-
 =head2 type_to_string
 
-Convert given file type into its three-letter printable ASCII/PETSCII string representation:
+Convert given file type into its three-letter printable ASCII string representation:
 
-  my $string = D64::Disk::Dir::Item->type_to_string($type, $as_petscii);
-
-C<as_petscii> defaults to false (meaning that ASCII characters will be returned by default).
+  my $string = D64::Disk::Dir::Item->type_to_string($type);
 
 =cut
 
 sub type_to_string {
-    my ($this, $type, $as_petscii) = @_;
+    my ($this, $type) = @_;
 
-    unless ($as_petscii) {
-        my @mapping = (
-            'del', # $T_DEL
-            'seq', # $T_SEQ
-            'prg', # $T_PRG
-            'usr', # $T_USR
-            'rel', # $T_REL
-            'cbm', # $T_CBM
-            'dir', # $T_DIR
-        );
+    my @mapping = (
+        'del', # $T_DEL
+        'seq', # $T_SEQ
+        'prg', # $T_PRG
+        'usr', # $T_USR
+        'rel', # $T_REL
+        'cbm', # $T_CBM
+        'dir', # $T_DIR
+    );
 
-        if ($type >= 0 && $type < @mapping) {
-            return $mapping[$type]
-        }
-        else {
-            return '???';
-        }
+    if ($type >= 0 && $type < @mapping) {
+        return $mapping[$type]
     }
     else {
-        my @mapping = (
-            '44454c', # $T_DEL
-            '534551', # $T_SEQ
-            '505247', # $T_PRG
-            '555352', # $T_USR
-            '52454c', # $T_REL
-            '43424d', # $T_CBM
-            '444952', # $T_DIR
-        );
-
-        if ($type >= 0 && $type < @mapping) {
-            return pack 'H*', $mapping[$type];
-        }
-        else {
-            return pack 'H*', '3f3f3f';
-        }
+        return '???';
     }
 }
 
@@ -1037,14 +851,6 @@ sub magic_to_int {
     return _magic_to_int($magic);
 }
 
-sub set_iok {
-    my ($self, $var) = @_;
-
-    my $var_iok = _set_iok($var);
-
-    return $var_iok;
-}
-
 =head1 BUGS
 
 There are no known bugs at the moment. Please report any bugs or feature requests.
@@ -1069,11 +875,11 @@ Pawel Krol, E<lt>pawelkrol@cpan.orgE<gt>.
 
 =head1 VERSION
 
-Version 0.08 (2023-05-12)
+Version 0.01 (2013-02-02)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013-2023 by Pawel Krol <pawelkrol@cpan.org>.
+Copyright 2013 by Pawel Krol <pawelkrol@cpan.org>.
 
 This library is free open source software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.8.6 or, at your option, any later version of Perl 5 you may have available.
 
